export declare type GridContainerConfig = HasId & HasStyleData & {
    type: "grid-container";
    layoutData?: {
        itemLayout?: LayoutGridItemLayout | LayoutFlexItemLayout;
        containerLayout?: LayoutGridContainerLayout;
        componentLayout?: LayoutComponentLayout;
    };
    children: [
        CellConfig | FragmentConfig | FlexContainerConfig | GridContainerConfig,
        ...(CellConfig | FragmentConfig | FlexContainerConfig | GridContainerConfig)[]
    ];
};
export declare type StyleClassList = string[];
export declare type LayoutGridItemLayout = LayoutItemLayoutShape & {
    type: "grid-item-layout-data";
    gridArea?: CssGridArea;
};
export declare type CssLength = {
    type: "px" | "vh" | "vw";
    value: number;
} | {
    type: "auto";
};
export declare type CssAlignment = "auto" | "stretch" | "center" | "start" | "end";
export declare type CssGridArea = [number, number, number, number];
export declare type LayoutFlexItemLayout = LayoutItemLayoutShape & {
    type: "flex-item-layout-data";
    /**
     * flex-grow
     */
    grow?: number;
    /**
     * flex-shrink
     */
    shrink?: number;
    /**
     * order
     */
    order?: number;
    /**
     * flex-basis
     */
    basis?: CssLength | CssPercentage;
};
export declare type CssTrackSize = CssNonNegativeAbsoluteLength | CssPercentage | {
    type: "fr";
    value: number;
};
export declare type CellConfig = HasId & HasStyleData & {
    type: "cell";
    definition: CellDefinition;
    layoutData?: {
        itemLayout?: LayoutGridItemLayout | LayoutFlexItemLayout;
        componentLayout?: LayoutComponentLayout;
    };
    metadata?: MetadataCell;
};
export declare type FragmentConfig = HasId & {
    type: "fragment";
    definition: FragmentDefinition;
    layoutData?: {
        itemLayout?: LayoutGridItemLayout | LayoutFlexItemLayout;
        componentLayout?: LayoutComponentLayout;
    };
};
export declare type FlexContainerConfig = HasId & HasStyleData & {
    type: "flex-container";
    layoutData?: {
        itemLayout?: LayoutGridItemLayout | LayoutFlexItemLayout;
        containerLayout?: LayoutFlexContainerLayout;
        componentLayout?: LayoutComponentLayout;
    };
    children: [FlexContainerItemConfig, ...FlexContainerItemConfig[]];
};
export declare type CssFlexDirection = "row" | "row-reverse" | "column" | "column-reverse";
export declare type CssFlexWrap = "nowrap" | "wrap" | "wrap-reverse";
export declare type CssOverflow = "auto" | "visible" | "hidden";
export declare type FlexContainerItemConfig = HasId & HasStyleData & {
    type: "flex-container-item";
    layoutData?: {
        itemLayout?: LayoutFlexItemLayout;
        containerLayout?: LayoutGridContainerLayout | LayoutFlexContainerLayout;
        componentLayout?: LayoutComponentLayout;
    };
    children: [CellConfig | FragmentConfig | FlexContainerConfig | GridContainerConfig];
};
export interface Configuration {
    packages?: Package[];
    route: Route;
    structure: GridContainerConfig;
}
export interface Package {
    name: string;
    version: string;
    archive: ArchiveTarball | ArchivePackage;
}
export interface ArchiveTarball {
    type: "tarball";
    uri: string;
}
export interface ArchivePackage {
    type: "npm";
    registry?: string;
}
export interface Route {
    name?: string;
    path: string;
}
export interface HasId {
    id: string;
}
export interface HasStyleData {
    styleData?: {
        classList?: StyleClassList;
    };
}
export interface LayoutItemLayoutShape {
    margin?: CssMargin;
    alignSelf?: CssAlignment;
    justifySelf?: CssAlignment;
}
export interface CssMargin {
    top?: CssLength | CssPercentage;
    right?: CssLength | CssPercentage;
    bottom?: CssLength | CssPercentage;
    left?: CssLength | CssPercentage;
}
export interface CssPercentage {
    type: "percentage";
    value: number;
}
export interface LayoutGridContainerLayout {
    type: "grid-container-layout-data";
    rows?: [CssTrackSize, ...CssTrackSize[]];
    columns?: [CssTrackSize, ...CssTrackSize[]];
}
export interface CssNonNegativeAbsoluteLength {
    type: "px" | "vh" | "vw";
    value: number;
}
export interface LayoutComponentLayout {
    type: "component-layout";
    width?: CssLength;
    height?: CssLength;
    minWidth?: CssLength;
    minHeight?: CssLength;
    maxWidth?: CssLength;
    maxHeight?: CssLength;
}
export interface CellDefinition {
    name: string;
    version: string;
    cell: string;
}
export interface MetadataCell {
    properties?: {
        [k: string]: unknown;
    };
}
export interface FragmentDefinition {
    type: "remote";
    uri: string;
}
export interface LayoutFlexContainerLayout {
    type: "flex-container-layout-data";
    direction?: CssFlexDirection;
    wrap?: CssFlexWrap;
    overflowX?: CssOverflow;
    overflowY?: CssOverflow;
}
